.. _subtractsky:

********************
Sky-Subtraction Step
********************

.. moduleauthor:: Christopher Hanley, Megan Sosey, Mihai Cara <help@stsci.edu>

.. automodule:: drizzlepac.sky
   :members: sky, help
   :undoc-members:
